HEIDI:
Previously on Project Runway...
Welcome to season 16
of Project Runway!
[whooping]
You should always be
expecting the unexpected.
TIM: This season,
you will be working
with models of all sizes.
I'm super nervous I might have
to work with a plus-size model.
♪ ♪
I would never have been able
to predict this.
Indeed.
♪ ♪
Deyonté.
Congratulations, you are
the winner of this challenge.
-DEYONTÉ: Thank you.
-[applause]
HEIDI: ChaCha. The construction
really was a mess.
I'm sorry.
That means you're out.
♪ ♪
BRANDON: You in the top;
how does that feel?
-Congratulations, man.
-Yeah.
DEYONTÉ:
I won the first challenge.
I kind of set the tone
for the competition.
So I'm really excited.
I'm just glad
that I'm still here.
-Yeah, girl. Yeah.
-We are, too. Yes.
BATANI: Being at the bottom
is not a good feeling.
And so, moving forward,
I'm thinking,
you know, I have
to really show me.
Ooh, guys.
Get over here.
-Oh, my God, no!
-[laughter]
"Good morning, designers."
"I've provided you with
some protective gear because..."
"For your next challenge, you're
gonna get down and dirty."
AYANA:
"There's no time to waste.
Go meet Tim
and a special guest..."
"To find out more. XOXO, Heidi."
-[gasps]
-No.
DEYONTÉ: Ooh, we got to get
down and dirty.
-Oh, man.
-I love it.
-Let's do it.
-SHAWN: This is gonna be good.
♪ ♪
DEYONTÉ [laughing]:
Oh, no...
We walk in,
and it's
a giant recycling center.
-Oh, my-- ugh.
-Oh, my God.
Place smells terrible, and I'm
wondering what we're gonna do.
-SAMANTHA: Aw, cute kitty.
-[meows]
-Hi.
-Hey.
TIM: Welcome
to Royal Waste Services,
one of the largest recycling
facilities in New York City.
ALL:
Wow.
TIM: And please welcome
our very special guest
and very dear friend,
Anne Fulenwider, editor-in-chief
of Marie Claire magazine.
-All right!
-Welcome, Anne.
ANNE:
Thanks, Tim.
I'm so excited
to be here with you,
and I'm really excited to tell
you about your next challenge.
The fashion industry has
a huge impact on our planet.
And now, more than ever,
we at Marie Claire
are focused on sustainability.
The dress I'm wearing is made
of 100% recycled trash.
-ALL: Wow.
-KENYA: Awesome.
SAMANTHA: I love the idea
of sustainability.
I know that fast fashion
is one of the biggest
contributors to pollution.
So this is your first
-unconventional materials
challenge. -[murmuring]
ANNE: For this challenge,
it is your job to not only
recycle and reuse
but also restyle.
TIM:
So you will be transforming
the recycled goods
all around you
into high fashion looks.
But there's a very
important detail.
This is your first
team challenge.
-ALL: Oh!
-BATANI: Yeah!
TIM:
All right, our first team member
of team one is Kudzanai.
Our second member is Michael,
Kentaro, Deyonté, and Margarita.
Team two begins with Aaron,
-Batani, Brandon...
-All right.
-Kenya, and Ayana.
-Oh.
TIM:
So, team three
is Sentell, Samantha, Amy,
Claire, and Shawn.
-So we have our teams.
-Yeah.
ANNE: And let me stress
that even though
you're working with
everyday recycled materials,
your designs should not
look everyday.
They should look high fashion.
You'll only have one day
for this challenge.
You will need to use
your time strategically.
ANNE: I have one more
exciting announcement.
The winning look will be
featured in a spread
in Marie Claire magazine
in a story about sustainability.
-ALL: Yeah.
-Awesome.
MARGARITA:
I want to win this challenge.
Unconventional materials
and a team challenge
and a magazine spread,
all rolled into one.
I'm ready.
On Anne's signal,
you'll have five minutes
to gather as many materials
as you can,
with your recycling bins.
-Is everybody ready?
-ALL: Yes.
ANNE:
Your time starts...
...now.
♪ ♪
DEYONTÉ:
Watch out, watch out.
KUDZANAI:
It's pandemonium.
Everybody's rushing for the same
piles of the same trash.
BRANDON:
This is my can.
One minute, everyone!
One minute!
AYANA:
I'm grabbing plastic,
these tray covers,
just little things that
I can add detail with.
All right, everyone! Time is up!
Designers, that's it.
KUDZANAI:
You guys are animals.
[inhales sharply]
-[exhales]
-That was a workout for the day.
I'm good. Ooh.
♪ ♪
[horns honking]
BATANI:
Where we at?
AYANA:
Over here, over here.
AMY:
Oh, it's so smelly.
It's like Easter
threw up in here.
-So we're-we're thinking
about... -Good heavens!
Wow!
[laughs]
All right. We have
our three design teams,
and each team of five
will be creating
a five-look mini-collection.
You have until 10:30 tonight.
So work like there's
no tomorrow.
You have a model card
inside your sketchbook.
You all have a new model
this challenge,
and we will continue
to rotate the models
so you'll all have
the opportunity to work
with models of different sizes.
I will be back later
to check in with you.
But do remember:
cohesion within the team.
-Have fun. Thank you.
-ALL: Thank you, Tim.
-Thank you.
-TIM: Thank you.
-What a great group.
-Nice. Yeah.
Uh, hi.
-Guys, here.
-Here's mine.
-Yes, let's definitely pick
a theme. -AARON: Okay.
AYANA: There's this thrift store
where I live,
-it's called Uptown Cheapskate.
-Okay.
So maybe we play on something
like that, 'cause it is trash.
AARON: Cheap upscale
or upscale cheap means
that, like, you're ballin'
on a budget.
-This is like...
-AYANA: Ballin' on a budget.
-Ballin' on a budget.
-BATANI: That's our theme.
All right. Our theme's
Ballin' on a Budget.
-That's my motto. Hey, man, love
you. -There you go, you did it.
♪ ♪
KUDZANAI: Our cohesive look
is we're telling a story.
Some kind of Japanese tale
of modern yet still
very fashion-forward.
-Yeah. -I got you.
-KENTARO: Yeah, let's start.
-MARGARITA: All right,
let's do it. -Okay.
AMY: And if we did something
like this, and...
-something that included...
-SENTELL: I was thinking more,
like, translucent
and very fluid-like.
AMY: But it can't look
like a Hefty bag,
-at the end of the day.
-Of course.
-Cruise! -AMY: Resort. -SENTELL:
Cruise, okay, I like that.
We're gonna go with resort,
we're going with sea glass
and translucent
to tie the whole collection.
♪ ♪
-Thank you.
-[chuckles]
-Samurai? You know?
-That would be cool.
-Japanese.
That would be really cool.
AARON: Brandon, your fabric
looks [bleep] k*ller, dude.
-You're liking it?
-Yeah, you're elevating
that fabric to another way.
-Yeah.
SAMANTHA: What I want to do--
'cause I'm-I'm really fast
at, like, braiding and weaving--
taking these, twisting them,
so they don't look
like plastic bags.
-I like that. -Okay. -How about
we look at braids as the idea,
-and then we'll each go to work.
-Okay. -Uh-huh.
I am not vibing
with the direction
that our team is going.
They're telling me,
"This is what we're doing,"
and I'm saying, "Okay. I guess."
Okay. What am I doing?
All right, I have to start,
'cause I'm starting
to freak out.
AYANA: I am nervous
about this challenge
because I am a modest designer,
and I want to show that
to the judges.
This is so messy.
The only thing that I'm seeing
is clear plastic.
So you will be able
to see straight through it.
Time is just moving so fast.
I don't know, I don't know,
I haven't figured it out yet.
SHAWN:
Last week I was in the bottom.
Now I have, like, the triple
whammy of a team challenge,
a unique material challenge,
and my first time working
with a plus-size model.
So I'm just... I'm-I'm really
overwhelmed, uh, right now.
CLAIRE: Let's not overthink it.
Let's not overthink it.
SHAWN:
I just, I-I...
I'm terrified
of the shame of failing.
HEIDI:
Coming up on Project Runway...
Oh!
-[groans]
-She seems kind of stressed out.
-You planned beautifully.
-Good.
I'm crazy about this.
This is not gonna help you.
-♪ Hallelujah. ♪
-[laughter]
There was utter elegance.
This is what this show is about.
I don't think there's a single
fashionable shape there.
You really need to change
your perspective.
It's like a leprechaun
went Dumpster diving.
Wow.
♪ ♪
-Oh! -I can't stand stuff
that isn't fabric.
SAMANTHA: The challenge
is to create high-end fashion
made from recycled materials,
and the prize is a spread
in Marie Claire
about sustainable fashion.
What if, instead of this,
you brought it like this?
-Okay. Yeah, that looks sexier.
-AMY: Yeah, exactly.
My individual plan is to stick
with the color scheme
and stick with
the braided cord idea.
AYANA: I don't have
the correct materials
to make what I want,
to make this full-length
modest dress.
You know,
I need to make this work.
And then a top
that's, uh, similar.
Um...
Yeah.
SAMANTHA: I'm really concerned
with Shawn.
She keeps redesigning her look.
[groans]
She seems kind of stressed out.
Is there anything we can do?
We just need to
get it done fast.
SAMANTHA:
I'm just frustrated because
we are all a team,
and... the burden's
on all of us.
Honestly, I love what you do.
-I think it's super cool.
-Thanks.
Growing up Muslim and wanting
to be fashionable,
I found that there is a shortage
in trendy, modest clothing.
♪ ♪
I'm definitely trying
to break the barrier
and show women that
you can still be Muslim,
you can still be modest
but still be
current and trendy
and fashion-forward.
Ah.
What's our team name?
-We were thinking Samurai.
-Did you talk about it?
Samurai?
-How about Wabi-sabi?
-Wabi-sabi?
-Yeah.
-What does that mean?
It's, like, Japanese,
like, you know,
like finding the beauty out of,
like, something very simple.
It's difficult to explain.
It's, like, very deep.
And it's art
but kind of going into, like,
you know,
connecting with the universe.
All right, team, that's good.
-Wabi-sabi.
-KENTARO: Wabi-sabi.
-Now I want sushi.
-[laughter] -Yum.
SENTELL:
We also need a team name.
-SAMANTHA: Yeah.
-SENTELL: Do you have any ideas?
-Uh... -I mean, we're starting
to work on the ocean,
-water, resort.
-Okay, um...
SAMANTHA:
Team Tsunami?
-Yeah.
-AMY: Love it.
-I love it.
-Let's check with the other two.
That's dope.
Good... heavens.
-[designers laugh]
-Hi, Tim!
TIM:
How are you all doing?
[designers groan, Tim laughs]
All right, Team Tsunami.
Tell me what you're doing.
So, we decided to do
a resort collection.
-We're each doing a look.
-Okay.
And our cohesion is being built
-from sharing elements.
-Okay.
These CD cases.
-Braiding. -Twisting
or braiding the plastics.
Samantha, this is you? I mean,
it's really been transformed.
-Talk to us.
-This is gonna be
open down the center.
And then,
this will be braided, too.
-I mean, I'm looking at
the vibe of Amy's, -Mm-hmm.
-and I'm looking at your vibe.
-Mm-hmm.
They feel like very different
customers.
Think about
the threads of DNA that can
connect these somehow
that make us
believe it's the same person.
-Sentell?
-So, I'm doing
an off-the-shoulder bustier.
For the neckline, I was thinking
of doing the braided
kind of vibe and I'm gonna use
this as, like, a jump ring.
What are you doing
in the bottom?
I was thinking a pair of shorts.
What would you make them out of?
[sighs]
Yeah, I-I'm not sure.
TIM: You have a lot
of resources here
that can really
move you forward.
So, Shawn, what are you doing?
I wanted to do more of a...
shapely bodycon.
-Where is it?
-So,
-it's in pieces.
-In pieces.
-SHAWN: Um...
-Of course!
I don't want to envelop her
-in these stiff fabrics.
-Right.
Because you don't want to be
on the bottom.
No, certainly not.
And not again.
-No.
-Indeed. Indeed.
How is Team Wabi-sabi?
-We're coming together
rather well. -We're good.
-How are you approaching this?
-MICHAEL: So the basic idea
behind our collection is a
Japanese garden being taken over
-by samurais.
-TIM: Okay.
With, kind of,
this textile that I created
with these plastic films.
And I'll curl them
so that it mimics a feather.
TIM: Okay, so,
is that the effect it will have?
-Yes. -Yeah.
-TIM: Oh. All right.
MARGARITA:
So, in the newspaper,
we just washed it out
with a little bit of white.
And then this I kind of
covered with vinyl
just to give it a little sheen.
It's so disparate.
-Mm-hmm.
-Here I see
a Japanese Mad Max.
And here I see...
You need elements that
bring these all together.
-How's Ballin' on a Budget?
-[laughter]
-KENYA: We are ballin'
on a budget. -Okay.
-Talk to me. -AYANA: Okay,
so with my look specifically,
I wanted to make sure that
I incorporated the modesty
aspect of what I do,
so mine is gonna be
-long fringe.
-Okay.
-[giggling]
-Kenya. What are you doing?
I wanted to stay
in my element far as...
-design aesthetic
-Of course.
and create a c*ck dress.
TIM:
It looks like I'm sitting
next to someone on the subway,
and I'm reading the part
of the paper they're not.
KENYA: I understand
what Tim has to say,
so I'm really trying
to calm myself down and try
to make a plan happen.
So, Brandon,
you're making this print?
Yes. I'm just finishing up
the patterning now,
so I don't have anything
to show on the form,
but I'm doing
a sleeveless jumpsuit
with a huge bell-bottom pant.
Does each of these pieces
of vinyl represent a piece
from which you're
going to cut a pattern?
-Exactly.
-Okay.
Well, you've planned
beautifully.
BATANI:
So, my girl, she's going
to an art gallery event.
I'm gonna make this
more structured.
I'm gonna use
some of the vinyl and some
of the brown paper bag material
to make the skirt flare out.
There is an overarching
principle of this challenge.
It's to work with these
unconventional materials
in such a way that
you're controlling them
and they're not controlling you.
And, Batani,
here's my concern about this.
It looks like this paper
is controlling you.
I'm gonna be a blunt instrument,
-because I'm most worried
about you. -Mm-hmm.
This is not gonna help you.
BATANI: My mind is
just turning, like, okay,
I'm just gonna scrap this
and create a new design.
TIM: All right, Aaron,
what are you doing?
I'm designing
for this party girl.
I kind of have these, like,
crazy, fringy pants
and a clear plastic top
that had a little bit
of everyone's material
confetti'd in it.
Are these five looks
coming out of the same closet?
And I'll be blunt with you--
it concerns me.
HEIDI:
Coming up on Project Runway...
SENTELL: Let's look
through the materials
and let's figure out
what we could do.
-What are you... I...
-Stop. Stop.
-Stop talking.
-Shawn's choking.
-[groans]
-We're in trouble, aren't we?
As individual pieces, I get it.
As a collection-- I'll be blunt
with you-- it concerns me.
Talk among yourselves about
how you can give some more depth
to these surfaces,
because they're rather flat.
-Okay.
-We can do that.
KENYA: We need to help
each other out and pull off
something that is phenomenal.
We don't have any other option.
All right, designers,
you all have a huge amount
of work to do.
I'm not going to mince words--
I'm worried.
Your models
are coming in at 7:30.
I have confidence in you!
-All right?
-Thank you. -Yes, Tim.
Make it work.
I'll see you in the morning.
-Good night. -Bye, Tim.
-Good night, Tim. -Bye-bye.
♪ ♪
-KENYA: I'm stressed.
-No, don't be stressed.
-No, oh, I'm stressed. -You're
too blessed to be stressed.
Oh, I'm blessed and I'm stressed
at the same time.
From Tim's advice,
we reevaluate everything.
We pull from Brandon's print,
we pull from Kenya's newsprint,
and my look
is gonna be one
that ties us all together,
where I literally use
a concept from everyone.
SAMANTHA: Sentell and I
are a little concerned with
the progress that...
Shawn is making.
SENTELL: Let's look through the
materials, and let's figure out
what we could do--
like, collectively, we can all,
-like, cohesively get something.
-And...
I... Oh, I'm the same way,
but it's all
-about staying here and getting
another chance. -Yes.
[overlapping chatter]
-Hi, ladies.
-Hello. -Hi!
BATANI: Tim has given me
another critique
that is not good.
So I just scrap
the whole design.
I decide to work
with the vinyl
and just add accents
of other materials.
So, how's this coming together
to work with everybody else's?
BRANDON:
Yeah, yeah. Yeah.
I can't be at the bottom again,
I-I just can't.
KENYA:
Oh, boy.
-Oh!
-[laughing]
Newspaper? Plastic?
What am I gonna do with that?
These kind of designs,
you can't move around
that much, you can't sit.
So I'm just like, okay, Monique,
are you ready for this?
Like, get it together.
[lively chatter]
-I'll see you tomorrow.
-Bye, ladies.
Yeah, here we go.
That looks so cute.
[line ringing]
Hi, babe!
I miss you so much, babe.
[voice breaks]:
I miss you, too, man.
So, the day before I came
to Project Runway,
I got married
to the love of my life,
and I didn't have
a chance to have any honeymoon
or any time
to spend with my husband.
Just know that I love you
and you're my main motivation.
I'm always thinking about you.
I think winning Project Runway
would be the best...
honeymoon surprise
for my husband and I.
I love you, baby.
All right, love you, babe. Bye.
Hammering.
♪ ♪
-Team Wabi-sabi is doing well.
-KUDZANAI: Yes. I really love
-how everything looks.
-KENYA: So?
-So?
-I smell... I-I smell a hater.
Got to make it do what it do.
AMY: So, towards the end
of this first day,
Shawn's lost it,
and she's-she's choking.
-I need...
-What are you... I...
Stop. Stop. Stop talking.
She's focused on Claire,
and she's not even working
on her design.
I want to put, like,
some other pieces here.
Watching this is-is honestly...
it's painful.
-Where are those pieces of
those... -I already took them.
We all have to be
"all hands on deck,"
and we've already got
two people practically
overboard.
[groans]
We're in trouble, aren't we?
[chuckles]
♪ ♪
SHAWN: I think I dropped
the ball on this one.
And I feel like it's my fault
if we're in the bottom.
I feel like our team could
definitely be in the bottom.
I don't know, I'm...
That's why I'm so nervous
about going into today.
You guys been looking around
at all?
You think there's
a top or a bottom?
-I'm feeling good about my look,
so... -BRANDON: Right.
-Well, let's get it in, guys.
-All right.
♪ ♪
KENYA: We sure do know how
to make a mess.
-Good morning. Wow. What a room.
-ALL: Good morning.
TIM: All right, if you're
in the Brother sewing
and embroidery studio,
listen up.
A lot can happen in two hours,
and you have two hours
this morning.
We say the long prayer.
TIM:
The JCPenney accessory wall
is your resource for styling
your looks for the runway.
And your models will be going
to the Avon Beauty Lab
and to our hair studio.
-ALL: Thank you, Tim.
-I love you guys.
-Love you, too.
-Wow.
KENTARO:
I love you.
♪ ♪
Focus.
[bleep]! [bleep]!
Ow! Ooh.
Yeesh! Sorry for
all the bad words.
-Hi, ladies!
-Hi, girls!
♪ ♪
Okay, that's good.
JAZZMINE: What I love
about Brandon's design is
the wide-leg pants,
because my thighs are huge.
The fact that he was able
to get that
and still make me look
really good-- I really love it.
[grunts]
It's not getting over.
Oh!
[groans]
Oh, Jesus!
It was a doozy getting into.
I gotta put some...
some paint...
a little bit of paint on.
It fits like it was
made for my body.
I can, like, move a little bit.
And it's just... I love it.
♪ ♪
Mm-hmm. It-it covers enough
of her side boob.
Shawn's look
has some fit issues.
-This is gonna be a hot mess.
-It looks fine.
You're not gonna have,
like, a range of movement.
Ayana's has a lot going on.
It's very creative, but,
you know, it kind of reminds me
of some Medieval Times-ish
kind of thing.
♪ ♪
Mwah! This is Janine.
-Hi, Janine.
-Okay, so today we're going
for, like, a Japanese theme.
-HECTOR: We start going outside
the line. -High fashion.
-Real high fashion. Yes.
-Okay.
-MARGARITA: Great.
-AYANA: Hi!
We want contour.
We want a lot of highlights.
HECTOR:
We have these mark. By Avon.
What I'm going to do
is do the darkest one,
just to give a little dimension.
AYANA:
Yeah.
So, we want to go
kind of beachy,
um, a little bit cruisy.
HECTOR: Touch & Glow.
That's going to give you
-that sun-kissed look.
-Mm.
It looks really natural.
All right, design teams,
in ten minutes,
you and your models and I
are going down to the runway!
Where the [bleep]
are my scissors?
Got to make it look good.
We have the most color.
We have the most texture.
-It's-it's very different.
-It's very different.
-We use the materials
in a great way. -This one.
-It's beautiful.
-Oh, no, no, no. We're not...
I feel that Sentell's design is
lacking a lot
of design elements to it.
I know he's a menswear designer,
but I think, for womenswear,
he might need
a little bit more time.
-Shawn!
-Designers and models,
-we are headed down
to the runway. -To the runway!
-Yay!
-TIM: Let's go, teams!
Go, go, go, go, go!
Slow but successful.
HEIDI:
Coming up on Project Runway...
-There was utter elegance.
-Very good.
-I'm so impressed.
-♪ Hallelujah. ♪
Something is confusing me.
This would look
like a really nice prom.
Yes.
[chuckles]
-Hello.
-[all greeting]
Welcome to the runway.
As you know, in fashion,
one day you're in,
and the next day you're out.
There are 15 of you here, and
after tonight there will be 14.
In this challenge,
you took sustainable fashion
to a whole new level.
You went to a recycling center
to gather your materials.
I love the unconventional
materials challenge.
It is my absolute favorite.
You worked
in three teams of five,
and you were to create
a high fashion,
five-look mini-collection
using your materials.
The winning look
will be featured
-in Marie Claire magazine.
-[sucks air through teeth]
Deyonté, you have immunity
and cannot be eliminated today.
All right,
let's say hello to our judges.
First, we have creative director
for Brooks Brothers Women
and fashion designer Zac Posen.
-Hi, designers!
-Hi, Zac! -Hey, Zac!
Creative director
for Marie Claire magazine,
-Nina Garcia. -Hi, everyone.
-Hi, Nina! -Nina.
Actress Maggie Q,
star of the hit series
Designated Survivor.
-Hi, everyone.
-ALL: Hi, Maggie! -Welcome!
Editor-in-chief of Marie Claire
magazine, Anne Fulenwider.
-Hi again.
-Hi! -Hi, Anne!
Also, we have Tim Gunn here
for the runway show.
And, as you know,
he is your mentor
and will not be judging
your looks.
We also have
an anonymous runway show,
so we, the judges, will not know
which designer created
which look.
All right? Let's start the show.
♪ ♪
MARGARITA:
I love the colors on her.
She is k*lling it.
The vinyl that I put over
the white painted newspaper
is really glistening.
I'm feeling like this
is setting the tone
for our team.
♪ ♪
KENTARO: I think my dress is
clean, so I'm happy with it.
But I wanted
to have more volume.
It looks good.
♪ ♪
DEYONTÉ:
The fabric is flowing.
It makes
the most beautiful silhouette.
It looks
like a real leather suit.
It's incredible.
♪ ♪
KUDZANAI: I love
how everything is moving.
I think it looks good.
♪ ♪
MICHAEL:
It's not my cleanest work.
But, to be honest,
from far away,
it just looks super cool.
And Liz
is completely working it.
♪ ♪
-Wow.
-It's shining.
KUDZANAI: Our team actually
looks like a collection
that you would walk into
a high-end boutique and find.
Hopefully we'll be
in Marie Claire.
♪ ♪
SENTELL: I'm definitely feeling
confident.
I feel that it's safe enough
to pass me through.
It looks beautiful on her,
and she sold it.
♪ ♪
SAMANTHA:
Samantha looks so beautiful.
She looks like
she's wearing real clothing
made of real fabrics
and not garbage.
♪ ♪
AMY: I feel that the garment
looks very attractive
and stylish.
The lights are going
through the colored discs.
It looks good.
♪ ♪
SHAWN:
It fits her well.
She feels comfortable
and confident.
It vibes with the collection.
I'm pleased.
♪ ♪
CLAIRE:
She is captivating.
She is stomping it out and
making my dress look top-notch.
♪ ♪
SHAWN: Our collection looks
very different.
I'm concerned
that we tried to be too safe,
too conservative,
and really missed that mark.
♪ ♪
BATANI:
My dress looks so cool.
The colors are popping.
She looks really futuristic.
I wanted to take it off
the model, wear it myself.
♪ ♪
AARON:
Oh, my God.
I see the shine in the top.
I see she is so confident.
We actually might have a chance
at winning this.
♪ ♪
KENYA:
My model was happy.
The dress is flowing perfectly.
The fit is right.
I'm very excited to see
what the judges have to say.
♪ ♪
BRANDON: Jazzmine's walking
down the runway,
and, I mean, she looks amazing.
I've been thinking
it's kind of the glue
to the whole collection, with
the head-to-toe checkered print
probably the most classic cut
of it all.
♪ ♪
AYANA: Meisha is bringing
my dress to life.
It's looking amazing,
and she is making me so proud.
♪ ♪
KENYA: I could not be happier
with my team.
Everyone came together, put
their ideas off on each other,
and we have
a pretty solid collection.
I think we're gonna be okay.
Some of the looks today
blew our mind.
They were amazing.
Others didn't impress us
so much.
There will be a winning team
and a losing team.
One member from the winning team
will be the winner
of this challenge, and
one member from the losing team
will be out.
Some of the looks today
blew our mind.
Others didn't impress us
so much.
One member from the winning team
will be the winner
of this challenge,
and one member from
the losing team will be out.
The winning team is...
...Ballin' on a Budget.
[laughs]
Oh, my gosh.
AARON:
Mm. Thank you.
HEIDI:
Congratulations, you guys.
Are you crying?
Are you crying, Kenya?
-BATANI: Yes.
-You really did blow us away.
The losing team is...
...Tsunami.
Wabi-sabi,
that means you're safe.
I'm going to talk
to the winning team first.
And then, Tsunami,
I'm gonna bring you back out.
You guys can leave the runway.
Thank you.
I'm confused, totally.
If they decide to say
who was the weakest,
do you guys
have that... figured out?
All right, team
Ballin' on a Budget,
please do explain and tell us
about your collection.
Our collection
is playing on futuristic,
uh, music festival.
We decided on the print
that Brandon came up with,
and we just wanted
to show that throughout.
After the critique,
Batani literally,
like, redesigned hers.
Aaron had the fringe,
and then we kind of just
tied it all together
with Kenya's newsprint.
My look was intended
to kind of be
a portion of everyone else's.
♪ Hallelujah. ♪
I am blown away.
-Wow. -Thank you. -Thank you.
-Thank you very much.
Great imagination.
And this is
what this show is about.
You guys did the best job
of transforming the materials,
especially this newsprint.
Batani, last week you had
one of the lower scores.
-Yes. -Good for you
for turning it around.
-Thank you, thank you.
-ANNE: When I saw that walk down
the runway today, I was like...
[gasps] "Yes! Fashion!"
-It's really fashion, it's
not just a dress. -Thank you.
I was particularly impressed
with Ayana.
The drama of the fringe--
there was utter elegance
to this dress.
ZAC:
Your bottle cap button back--
-it's clever.
-NINA: The buttons in the back--
that was like,
"Oh, there goes my heart."
KENYA: Mm-hmm.
[laughs]
HEIDI:
So you are the winning team,
but only one of you
will be the winner.
I would like to know
who you think that should be.
Well, I really like
Ayana's dress.
I think she should win.
I think Brandon. I don't know,
he was kind of the glue to us.
I guess, Aaron,
just because that's, like,
maybe something closer
to what I would make.
I would pick Ayana.
She was a team player.
I'm very, very proud of her.
Wow, thank you.
Ayana, what about you?
My favorite piece... is Kenya's.
I love you.
Okay, we've heard
what you had to say.
Now we're going to talk
to the losing team next,
and then I'm gonna
bring you back in a little bit.
You can leave the runway.
Thank you.
-Thank you. -Thank you.
-Thank you very much.
Cool.
Team Tsunami,
you are the losing team.
Please tell us
about your collection.
So, we went with
a resort-wear theme
and just tried
to incorporate the materials
that we had found into...
the collection.
Some of these pieces I'm looking
at, and I still see garbage.
I don't see anything looking
like fabric all of a sudden.
In some pieces I do.
Samantha, I feel like
in your top I do.
It looks sharp.
The amazing braid effect
of that halter top
should have been the main detail
-throughout the collection.
-Yes. -Yes. -Thank you.
Sentell, how long
did you work on your outfit?
I finished
a little early, and...
What do you mean, like,
"a little early"?
An hour or two early.
HEIDI: I'm surprised to hear
that you had so much time left,
because it looks like
you made it in ten minutes.
ZAC:
It doesn't feel transformed.
It's like a leprechaun
went Dumpster diving.
Recycling is very much
a reality
of our fashion future.
So for you guys
to be so short-sighted
about the possibilities of this
is very disappointing.
If I may say, I think, perhaps,
it may have been,
uh... fear.
ZAC:
You got to take risks.
It's-it's baffling to me,
quite frankly, this whole thing.
And, Shawn, actually, yours,
I don't mind as much.
-Very good. -HEIDI: You know,
when I look at your skirt,
it actually fits pretty well.
Also, the halter--
it looks quite nice.
-I actually sewed the halter
top. -I mean, the slit
is maybe... Oh, you did?
-Well done.
-Thank you.
HEIDI: I thought everyone
did just their girl.
The braid on mine, Samantha did.
I did everything else.
And I did, uh, Shawn's top.
-Well...
-The textile was made
by Shawn, but I made the look.
You guys spent a lot of time
making
-this Warhol silver fabric.
-I painted all of it.
ANNE: I think the silver
is great, and it's actually...
it's one of the better notes
of cohesion.
A lot of it was rushed.
Like, Shawn's look
didn't get assembled till
this morning, and we were all
-working on putting it together
with her. -[Heidi laughs]
I love how the two of you
do the same annoyed face
-at the same time.
-Yeah... -Well...
SENTELL: But-but it's true--
all three of us did help
-finish the twins' look, right?
-And we wanted to work
-as a team. -I don't think
that that's quite accurate.
I think that is very accurate.
If I may quote you, you said,
"I dropped the ball
for you guys."
-That's not incorrect. I won't
say that. -Thank you very much.
I want to understand,
'cause something's confusing me.
CLAIRE:
If I may-- what Shawn was
having an issue with is that
this was a new experience
for her,
having never worked
with a curvier model.
-Can I just say, that's...
-Okay, you know what...
-she's not curvy.
-ANNE: She's not that curvy.
MAGGIE: I'm, like, shocked
that you're saying she's curvy.
If you think that's curvy,
you're gonna have a real problem
designing in the United States,
because that is not curvy.
-Um... -So you really need
to change your perspective.
And who do you
normally design for?
Singers, celebrities,
-people in the entertainment
industry. -Pop stars.
-Got it. -ANNE: Even if you had
the perfect materials,
your perfect model,
this would look like
a really nice prom.
NINA:
This is a team challenge.
When all of them are bad,
there is not salvaging anything.
It's about the team.
SHAWN:
If I were to say one
that doesn't fit most,
it's Amy's.
-In some ways...
-HEIDI: Here's that bus.
-That bus just came right out.
-[laughs] -Sure did. -Oh, wow.
HEIDI:
But, Shawn,
since you rolled that bus
onto that stage,
I want to know who you think
is the weakest designer.
For the sake of time management,
it was me.
Stylistically,
it would probably be Amy's.
AMY: While I do think Shawn
does have a lot of talent,
I would probably choose
to send her to come back
another time.
I like you, I just want you
to be able to, like,
lift yourself up
after each time,
and I don't know if you can.
-[sighs] -HEIDI:
Sentell, what do you think?
It would have to be one of
the twins. It would be Shawn.
They both had, uh, problems
designing and constructing
their looks.
If I may, I nearly sewed
the entire silver dress myself.
HEIDI: So who do you think
should go home?
Sentell should go home.
I didn't really care for the way
that the dress was ex*cuted.
Okay, we've heard
what you had to say.
Now we're going to take
a closer look
at your designs,
have a big chat,
and then I'm gonna bring you
back onto the runway.
Now you can leave the runway.
Thank you.
HEIDI: The winner of
Project Runway will receive
the opportunity to collaborate
with JCPenney
on a limited edition
capsule collection as part
of the Project Runway line sold
at select JCPenney stores
and online at JCP.com;
a selection of Brother sewing
and embroidery machines,
with a retail value of $40,000;
makeup and beauty products
for a year, courtesy of Avon;
the new 2018 Lexus NX,
coming this fall
with advanced innovation
and safety system standard;
from the Pilot FriXion
Erasable Pen,
the official pen
of Project Runway,
a lifetime supply of pens
and an all-expense-paid luxury
trip to Japan,
including a five-star stay
near Japan's fashion center;
$100,000 to launch their line;
and the winning designer
and model will receive
a fashion spread
in Marie Claire magazine.
-Hello, Tim.
-TIM: Hello.
Do you want to bring
-each model out individually?
-Yes. -Yeah.
-TIM: Marsha's wearing Batani.
-ZAC: Oh, cool.
She remade one here.
TIM: She rallied,
and look what happened.
It's been
completely transformed.
Christina's wearing Aaron.
ZAC: I love that they played
with the transparency,
and that it floats
around your leg.
It feels fashion,
it feels emotional.
And Monique is wearing Kenya.
HEIDI: I mean, this is pretty
fabulous. -NINA: Fabulous.
-MAGGIE: It's beyond. -ANNE:
The-the fabric is amazing.
It's a proper dress.
-And Jazzmine is wearing
Brandon. -I love this.
HEIDI: She has to pull this off
and make this look
light and breezy, these pants.
That's what makes it so special.
And Meisha is wearing Ayana.
-Wow. -NINA: This was magic.
-MAGGIE: Beyond.
You have to do your spin.
It's cool.
-So do you want to look at it
look by look? -ZAC: Yeah.
TIM: So we have Samantha
wearing Samantha.
You know, this was effective,
this braided trim here.
-Beautiful. Beautiful.
-ANNE: That's beautiful. -Yes.
HEIDI: I mean, I think,
out of all of them,
this was the best look.
And we have Sian wearing Amy.
HEIDI:
Ugh. Wah-wah.
-ANNE: Should we take off
the jacket? -No. -No.
HEIDI: What's underneath it
is also not great.
Liris will come out
wearing Claire.
ANNE: If she took off
all the extra stuff
and just had a silver top
and skirt, pretty cool.
TIM: We have Sanita
wearing Sentell.
-Sentell had a lot of talk about
the form. -It is a garbage bag.
-ZAC: It's hanging together.
-HEIDI: It's garbage.
He thought it was good.
We have Kylie wearing Shawn.
There was this whole issue
with who made the top.
It's surprising that
"We don't know how
to make clothing
for curvy girls."
Grow up and make clothes
for real people.
Okay, so we've made
our decision.
Let's bring them back out.
Team Ballin' on a Budget,
there was one designer's look
that really stood out.
Ayana, you are the winner
of this challenge.
Congratulations.
Oh, my gosh. Thank you.
HEIDI: Your design will appear
in Marie Claire magazine.
[laughter]
Wow.
-HEIDI: Congratulations.
-Thank you.
Well, you can all leave
the runway.
Thank you so much.
♪ Ah ♪
To have Heidi say my name
is everything.
I went from watching
Project Runway at home,
now I'm in it.
I'm so excited to be at the top.
You're gonna be in Marie Claire.
-Yes. Seriously.
-[whooping]
-This is really important to me.
[sniffles] -Yeah.
HEIDI:
Team Tsunami,
you were the losing team,
and one of you will be out.
Samantha, Amy, Claire...
...the three of you are in.
You can leave the runway.
Thank you.
Shawn, Sentell,
one of you will be out.
Shawn...
...you're in.
You can leave the runway.
Thank you.
Sentell, I'm sorry.
That means you're out.
Thank you.
I'm humbled by this experience.
Thank you so much.
-I finally get to see
my husband. -HEIDI: Aw.
-I got married the day before
I came here. -Aw.
So I had no honeymoon.
-Auf Wiedersehen.
-Thank you.
-Thank you.
-Thank you so much.
Thank you.
[sighs]
Um...
DEYONTÉ:
Sentell.
ALL:
Aw.
[Deyonté groans]
Dude.
SENTELL:
Of course,
I feel extremely saddened
by being eliminated.
Yeah, like,
I came a long way, so...
DEYONTÉ: Everybody's
watching this, proud of you.
-[laughter]
-Oh...
-How is everyone?
-It's rough.
-TIM: It's rough.
-Rough.
And, Sentell, we are going
to so sincerely miss you.
Thank you so much, Tim,
I appreciate it.
-I have to send you to
the workroom. Okay? -Thank you.
-You take care.
-All right, guys, see you.
-We know we're gonna hear
more from you. -Bye.
-Thank you. [groans]
-Whoops.
-[laughter]
-There we go.
Just making it on the show
and being able to learn
from all of the people
that I've met here,
I'm a winner.
I'm gonna go home and I'm going
to continue to push on,
because you never,
ever, ever give up.
HEIDI:
Next time on Project Runway...
Move those hips.
Shake your little booty.
[all laughing]
We want your next look
to be inspired by dance,
movement, and innovation.
[yelps]
-[whoops]
-[yells]
-Okay? Ooh!
-Aah!
Aah, aah.
-Oh, God.
-Good heavens.
I just don't want it
to get too gimmicky.
-Wow.
-It is fabulous.
It's absolutely stunning.
It made me want to dance.
Ooh.
It's too, too, too much.
-Surprise!
-Ugh.
Visit myLifetime.com
to learn more about
the fashion you've seen
on tonight's show.
Welcome to our World! Where we serve you cookies to ensure you get the best viewing experience on our site.
Did you know that you can remove censorship board-wide, use our advanced search functions, be notified when new content is posted, join our memberships, set episodes to show in any order you want & more if you are logged into your account?
Register or sign in here: ucp.php?mode=register
Did you know that you can remove censorship board-wide, use our advanced search functions, be notified when new content is posted, join our memberships, set episodes to show in any order you want & more if you are logged into your account?
Register or sign in here: ucp.php?mode=register
16x03 - An Unconventional Recycling
Watch/Buy Amazon
Contestants compete with each other to create the best clothes and are restricted by time, materials and theme.
Contestants compete with each other to create the best clothes and are restricted by time, materials and theme.